# mDNS support for BrewBlox systems

BrewPi Spark controllers broadcast themselves as mDNS services to allow automatic detection.

This application allows for browsing for mDNS devices, with or without specific ID.
